from django.test import TestCase

from ..models import AppTemplate


# add some basic things (admin list view, detail view, etc)
class AppTemplateTests(TestCase):

    def fetch_objs(self):
        all = AppTemplate.objects.all()
        self.assertEqual(all.count(), 0)



from cms.models import PlaceholderField
from django.urls import reverse
from django.db import models
from django.utils.text import slugify
# from filer.fields.image import FilerImageField
from filer_addons.filer_gui.fields import FilerImageField

from project.managers import PublishedQuerySet
from project.models import PublishedBase, SEOBase


class AppTemplate(PublishedBase, SEOBase, models.Model):
    date = models.DateField()
    title = models.CharField(max_length=255)
    preview_text = models.TextField(blank=True, default='')
    preview_image = FilerImageField(on_delete=models.PROTECT, default=None, null=True)
    content = PlaceholderField(slotname='content')

    objects = PublishedQuerySet.as_manager()

    class Meta:
        ordering = ('-date', )

    def get_slug(self):
        return slugify(self.get_seo_title())

    def get_absolute_url(self):
        return reverse('article_detail', args=(self.id, self.get_slug()))

    def __str__(self):
        return u'%s' % (self.title, )



# -*- coding: utf-8 -*-
# Generated by Django 1.11.29 on 2020-09-28 07:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('test_app', '0005_auto_20200211_1615'),
    ]

    operations = [
        migrations.AddField(
            model_name='testinlinemodel',
            name='field1_de',
            field=models.CharField(default='', max_length=64, null=True),
        ),
        migrations.AddField(
            model_name='testinlinemodel',
            name='field1_en',
            field=models.CharField(default='', max_length=64, null=True),
        ),
        migrations.AddField(
            model_name='testinlinemodel',
            name='field1_fr',
            field=models.CharField(default='', max_length=64, null=True),
        ),
        migrations.AddField(
            model_name='testmodel',
            name='field1_de',
            field=models.CharField(default='', max_length=64, null=True),
        ),
        migrations.AddField(
            model_name='testmodel',
            name='field1_en',
            field=models.CharField(default='', max_length=64, null=True),
        ),
        migrations.AddField(
            model_name='testmodel',
            name='field1_fr',
            field=models.CharField(default='', max_length=64, null=True),
        ),
    ]



from modeltranslation.translator import translator, TranslationOptions
from .models import TestPluginModel, TestModel, TestInlineModel


class TestPluginModelTranslationOptions(TranslationOptions):
    fields = ('field1', )


translator.register(TestPluginModel, TestPluginModelTranslationOptions)


class TestModelTranslationOptions(TranslationOptions):
    fields = ('field1', )


translator.register(TestModel, TestModelTranslationOptions)


class TestInlineModelTranslationOptions(TranslationOptions):
    fields = ('field1', )


translator.register(TestInlineModel, TestInlineModelTranslationOptions)



from django.urls import path

from .views import AppTemplateListView, AppTemplateDetailView


urlpatterns = [
    path('', AppTemplateListView.as_view(), name='apptemplate_list'),
    path('detail/<int:pk>/<slug:slug>/$', AppTemplateDetailView.as_view(), name='apptemplate_detail'),
]



from modeltranslation.translator import TranslationOptions
from modeltranslation.decorators import register

from .models import AppTemplate


@register(AppTemplate)
class AppTemplateTranslationOptions(TranslationOptions):
    fields = ['title', ]



from django.views.generic import ListView, DetailView

from .models import AppTemplate
from .views_utils import PublishedViewMixin, AutoSlugMixin, LanguageChooserEnhancerMixin


class AppTemplateListView(PublishedViewMixin, ListView):
    model = AppTemplate


class AppTemplateDetailView(
    AutoSlugMixin,
    PublishedViewMixin,
    LanguageChooserEnhancerMixin,
    DetailView,
):
    model = AppTemplate
